# ListElevatedUserRoles

Respose object for a elevated user roles query
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**elevated_permissions** | [**list[UserRoles]**](UserRoles.md) | List of elevated user roles | [optional] 
**limit** | **int** | Limit the number of responses | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


